@@ -12,7 +12,9 @@ from .md_utils import (get_md_relpaths_matching_subdirs, get_unique_md_links,
                        get_embedded_files,
                        get_front_matter,
                        get_tags,
-                       _get_ascii_plaintext_from_md_file)
+                       _get_source_text_from_md_file,
+                       _get_readable_text_from_md_file,
+                       _get_all_latex_from_md_file)
 
 
 class Vault:
@@ -62,10 +64,11 @@ class Vault:
             get_backlink_counts
             get_wikilinks
             get_embedded_files
+            get_math
             get_front_matter
             get_md_links
             get_tags
-            get_text
+            get_source_text
 
         Methods for analysis across multiple notes:
             get_note_metadata
@@ -76,12 +79,14 @@ class Vault:
             backlinks_index
             wikilinks_index
             embedded_files_index
+            math_index
             md_links_index
             tags_index
             nonexistent_notes
             isolated_notes
             graph
-            text_index
+            source_text_index
+            readable_text_index
             is_connected
             is_gathered
         """
@@ -97,12 +102,14 @@ class Vault:
         self._backlinks_index = {}
         self._wikilinks_index = {}
         self._embedded_files_index = {}
+        self._math_index = {}
         self._md_links_index = {}
         self._tags_index = {}
         self._nonexistent_notes = []
         self._isolated_notes = []
         self._front_matter_index = {}
-        self._text_index = {}
+        self._source_text_index = {}
+        self._readable_text_index = {}
 
     @property
     def dirpath(self):
@@ -133,10 +140,16 @@ class Vault:
 
     @property
     def embedded_files_index(self):
-        """dict: note name (k) to embedded file strimg (v).  v is [] if
-        k has no embedded files."""
+        """dict: note name (k) to list of embedded file strimg (v).
+        v is [] if k has no embedded files."""
         return self._embedded_files_index
 
+    @property
+    def math_index(self):
+        """dict: note name (k) to list of LaTeX math strimg (v).  v is [] if
+        k has no LaTeX."""
+        return self._math_index
+
     @property
     def md_links_index(self):
         """dict of lists: filename (k) to lists (v).  v is [] if k
@@ -182,10 +195,24 @@ class Vault:
         return self._is_gathered
 
     @property
-    def text_index(self):
-        """dict of strings: filename (k) to plaintext string (v).  v is ''
-        if k has no text."""
-        return self._text_index
+    def source_text_index(self):
+        """dict of strings: filename (k) to source text string (v).  v is ''
+        if k has no text.
+
+        Source text aims to preserve as much of the text written to a file
+        as possible.  This is done through the use of pymarkdown extensions
+        to maintain the additional markdown features that Obsidian uses."""
+        return self._source_text_index
+
+    @property
+    def readable_text_index(self):
+        """dict of strings: filename (k) to 'readable' string (v).  v is ''
+        if k has no text.
+
+        Readable text has all the main formatting removed.  This makes it
+        easier to use the text for NLP analysis, with minimal processing
+        needed, while still maintaining the meaning of text."""
+        return self._readable_text_index
 
     def connect(self):
         """connect your notes together by representing the vault as a
@@ -208,30 +235,46 @@ class Vault:
             self._nonexistent_notes = self._get_nonexistent_notes()
             self._isolated_notes = self._get_isolated_notes(graph=G)
             self._embedded_files_index = self._get_embedded_files_index()
+            self._math_index = self._get_math_index()
             self._front_matter_index = self._get_front_matter_index()
 
             self._is_connected = True
 
         return self  # fluent
 
-    def gather(self, *, remove_code=True):
+    def gather(self, *, tags=None):
         """gather the content of your notes so that all the plaintext is
-        stored in one place for easy access.  The content of each note is
-        stored in the note_index attribute.
+        stored in one place for easy access.
+
+        The content of each note is stored in the source_text_index attribute.
+        This enables text from the files to be accessible in one place.
+
+        The stripped down content of the notes' text is stored in the
+        readable_text_index attribute.  This enables text to be used more
+        easily in NLP analysis.
 
         With your vault connected, gather your note content through:
             vault.gather()
 
         Args:
-            remove_code (Bool): remove code blocks from the note content.
-                Defaults to True.
+            tags (list, optional): Defaults to None, to keep all headers
+                and paragraph formatting in the readable_text for notes.
+                Otherwise specify a list of HTML tags to use to preserve
+                their formatting in the final text.  For example, tags=[]
+                will remove all header formatting (e.g. '#', '##' chars)
+                and produces a one-line string.
         """
         if not self._is_connected:
             raise AttributeError('Connect vault before gathering notes.')
 
-        self._text_index = {
-            k: _get_ascii_plaintext_from_md_file(self._dirpath / v,
-                                                 remove_code=remove_code)
+        # source text will not remove any content:
+        self._source_text_index = {
+            k: _get_source_text_from_md_file(self._dirpath / v,
+                                             remove_code=False)
+            for k, v in self._file_index.items()}
+        self._readable_text_index = {
+            k: _get_readable_text_from_md_file(self._dirpath / v,
+                                               tags=tags)
             for k, v in self._file_index.items()}
 
         self._is_gathered = True
@@ -390,11 +433,9 @@ class Vault:
         else:
             return self._tags_index[file_name]
 
-    def get_text(self, file_name):
+    def get_source_text(self, file_name):
         """Get text for a note (given its filename).  This requires the vault
-        functions 'connect' AND 'gather' to have been called.  Change the
-        arguments of the 'gather' function to specify how the text of notes
-        should be read, e.g. whether code blocks should be included.
+        functions 'connect' AND 'gather' to have been called.
 
         Text can only appear in notes that already exist, so if a
         note is not in the file_index at all then the function will raise
@@ -412,7 +453,34 @@ class Vault:
         if file_name not in self._file_index:
             raise ValueError('"{}" does not exist so it cannot have text.'.format(file_name))
         else:
-            return self._text_index[file_name]
+            return self._source_text_index[file_name]
+
+    def get_readable_text(self, file_name):
+        """Get readable text for a note (given its filename).
+        This requires the vault functions 'connect' AND 'gather' to have
+        been called.
+
+        Change the arguments of the 'gather' function to specify how the text
+        output should be stored, e.g. whether all HTML tags should be removed
+        before the final output.
+
+        Text can only appear in notes that already exist, so if a
+        note is not in the file_index at all then the function will raise
+        a ValueError.
+
+        Args:
+            file_name (str): the filename string that is in the file_index.
+                This is NOT the filepath!
+
+        Returns:
+            str
+        """
+        if not self._is_gathered:
+            raise AttributeError('Gather notes before calling the function')
+        if file_name not in self._file_index:
+            raise ValueError('"{}" does not exist so it cannot have text.'.format(file_name))
+        else:
+            return self._readable_text_index[file_name]
 
     def _get_md_relpaths(self, **kwargs):
         """Return list of filepaths *relative* to the directory instantiated
@@ -447,6 +515,13 @@ class Vault:
         return {k: get_embedded_files(self._dirpath / v)
                 for k, v in self._file_index.items()}
 
+    def _get_math_index(self):
+        """Return k,v pairs
+        where k is the md filename
+        and v is list of ALL LaTeX math strings found in k"""
+        return {k: _get_all_latex_from_md_file(self._dirpath / v)
+                for k, v in self._file_index.items()}
+
     def _get_unique_wikilinks_index(self):
         """Return k,v pairs
         where k is the md filename
